/*
 epiclccorr

   Authors:  Aitor Ibarra - XMM-Newton SOC ESAC/ESA

   Description: The aim of this task is to correct EPIC source time series.

   Comments:

  $Id: epiclccorr.cc,v 1.4 2009/07/16 10:41:39 aibarra Exp $
*/

#include <vector>
#include <string>
#include "epiclccorr.h"
#include "LightCurve.h"
#include <Tracer.h>
#include <errstr.h>


void epiclccorr ()
{
PROC
	/*
	 * List of the source time series
	 */
	string srcTSList = stringParameter("srctslist");

	/*
	 * List of the original event files
	 */
	string evtList = stringParameter("eventlist");

	/*
	 * Output name
	 */
	string outFileName = stringParameter("outset");


	/*
	 * Creates the source Light Curve
	 */
	LightCurve *srcLC = new LightCurve(srcTSList, evtList);


	/*
	 * Apply relative corrections
	 */

	srcLC->doRelativeCorr();

	/*
	 * Calculates BACKSCALE value for source time serie
	 */
	if ( ( booleanParameter("withbkgset") ) ||
			(booleanParameter("applyabsolutecorrections")) )
	{
		srcLC->calSpec();
		// arfgen modifies the spectrum with the correct backscale.
		srcLC->getSpec()->calArfgen(Spec::SRC);
		srcLC->getSpec()->readSpec();
	}

	/*
	 * Check if we have to apply absolute corrections
	 */
	if (booleanParameter("applyabsolutecorrections"))
	{
		srcLC->getSpec()->readArf(Spec::SRC);
		srcLC->getSpec()->calArfgen(Spec::ON);
		srcLC->getSpec()->readArf(Spec::ON);
		srcLC->doAbsoluteCorr();
	}
	// Remove src ancillary file
	if ( ( booleanParameter("withbkgset") ) ||
			(booleanParameter("applyabsolutecorrections")) )
		srcLC->getSpec()->removeArfFile();

	srcLC->getLC()->calRateAndErr();


	/*
	 * Check if a bkg light curve have been supplied and create the
	 * corresponding light curve.
	 * Calculate relative corrections and absolute corrections for background
	 * time serie
	 */
	LightCurve *bkgLC = 0;
	if (booleanParameter("withbkgset"))
	{
		string bkgTSName = stringParameter("bkgtslist");
		bkgLC = new LightCurve(bkgTSName, evtList);

		bkgLC->doRelativeCorr();

		/*
		 * Calculation of  BACKSCALE
		 */
		bkgLC->calSpec();
		bkgLC->getSpec()->calArfgen(Spec::BKG);
		bkgLC->getSpec()->readSpec();
		bkgLC->getLC()->calRateAndErr();


		/*
		 * Substract background
		 */
		srcLC = srcLC->operator-(bkgLC);
	}



	if (booleanParameter("applyabsolutecorrections"))
		srcLC->applyAbsCorr();


	srcLC->createFile(outFileName);

	delete srcLC;
	delete bkgLC;


ENDPROC
}
